/*
 * sysconfig.hpp -- configuration for irccd
 *
 * Copyright (c) 2013-2019 David Demelier <markand@malikania.fr>
 *
 * Permission to use, copy, modify, and/or distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

#ifndef IRCCD_SYSCONFIG_HPP
#define IRCCD_SYSCONFIG_HPP

/*
 * Fix annoying "Please include winsock2.h before windows.h"
 */
#if defined(_WIN32)
#	if !defined(WIN32_MEAN_AND_LEAN)
#		define WIN32_MEAN_AND_LEAN
#	endif
#	if !defined(NOMINMAX)
#		define NOMINMAX
#	endif

#	include <winsock2.h>
#	include <windows.h>
#endif

namespace irccd {

/*
 * Auto generated from CMake.
 * ------------------------------------------------------------------
 */

#define IRCCD_VERSION_MAJOR             3
#define IRCCD_VERSION_MINOR             0
#define IRCCD_VERSION_PATCH             3
#define IRCCD_VERSION_SHLIB             1
#define IRCCD_VERSION                   "3.0.3"

/*
 * User definable options.
 * ------------------------------------------------------------------
 */

#define IRCCD_INSTALL_PREFIX            "/usr"
#define IRCCD_INSTALL_LOCALSTATEDIR     "var"
#define IRCCD_INSTALL_DATADIR           "share"
#define IRCCD_INSTALL_BINDIR            "bin"
#define IRCCD_INSTALL_LIBDIR            "lib"
#define IRCCD_INSTALL_SYSCONFDIR        "/etc"

#define IRCCD_HAVE_JS
#define IRCCD_HAVE_SSL
#define IRCCD_HAVE_LIBEDIT

/*
 * Platform checks.
 * ------------------------------------------------------------------
 */

#define IRCCD_HAVE_POPEN
/* #undef IRCCD_HAVE_SETPROGNAME */
#define IRCCD_HAVE_STAT
#define IRCCD_HAVE_STAT_ST_ATIME
#define IRCCD_HAVE_STAT_ST_BLKSIZE
#define IRCCD_HAVE_STAT_ST_BLOCKS
#define IRCCD_HAVE_STAT_ST_CTIME
#define IRCCD_HAVE_STAT_ST_DEV
#define IRCCD_HAVE_STAT_ST_GID
#define IRCCD_HAVE_STAT_ST_INO
#define IRCCD_HAVE_STAT_ST_MODE
#define IRCCD_HAVE_STAT_ST_MTIME
#define IRCCD_HAVE_STAT_ST_NLINK
#define IRCCD_HAVE_STAT_ST_RDEV
#define IRCCD_HAVE_STAT_ST_SIZE
#define IRCCD_HAVE_STAT_ST_UID
#define IRCCD_HAVE_STD_PUT_TIME
#define IRCCD_HAVE_SYSLOG

/**
 * \brief Describe irccd version.
 */
struct version {
	const unsigned major{IRCCD_VERSION_MAJOR};      //!< major
	const unsigned minor{IRCCD_VERSION_MINOR};      //!< minor
	const unsigned patch{IRCCD_VERSION_PATCH};      //!< patch
	const unsigned abi{IRCCD_VERSION_SHLIB};        //!< ABI compatibility
};

} // !irccd

#endif // !IRCCD_SYSCONFIG_HPP
